@@ -1,7 +1,7 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "notmuch" "0.40"
+(define-package "notmuch" "20250620.1557"
   "Run notmuch within emacs."
   ()
   :url "https://notmuchmail.org"
-  :commit "cee41bccc054617b0cffe12759b209ff66066563"
-  :revdesc "0.40-0-gcee41bccc054")
+  :commit "63665f1ebd6eff7753b7798add657fd6dbd110d6"
+  :revdesc "63665f1ebd6e")
